# Planetcantile


Adds TileMatrixSets for other planets.
Aims to be home to a wide range of tilesets for the Moon, Mars, and more.

Integrates with [morecantile](https://github.com/developmentseed/morecantile), ideally should allow downstream projects to benefit from additional TMSs defined here.

Definitions go into the generate.py script to have fine grain control, alternatively json files can just be added directly to the data directory.

